# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorarch: %global perl_vendorarch %(eval "`perl -V:installvendorarch`"; echo $installvendorarch)}

# work around upstream versioning being decimal rather than v-string
%global upstream_version 4.12
%global extraversion %{nil}
%if "%{upstream_version}%{extraversion}" != "%{upstream_version}"
Provides:	perl(IO::AIO) = %{upstream_version}%{extraversion}
%endif

Name:		perl-IO-AIO
Version:	%{upstream_version}%{extraversion}
Release:	1.%{__distinit}%{__distvers}
Summary:	Asynchronous Input/Output
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/IO-AIO/
Source0:	http://search.cpan.org/CPAN/authors/id/M/ML/MLEHMANN/IO-AIO-%{upstream_version}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	perl >= 3:5.8.2
BuildRequires:	perl(Carp)
BuildRequires:	perl(common::sense)
BuildRequires:	perl(ExtUtils::MakeMaker)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%{?perl_default_filter}

%description
This module implements asynchronous I/O using whatever means your operating
system supports.

%prep
%setup -q -n IO-AIO-%{upstream_version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}

# Remove script we don't want packaged
rm %{buildroot}%{_bindir}/treescan

find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
chmod -R u+w %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes COPYING README
%{perl_vendorarch}/auto/IO/
%{perl_vendorarch}/IO/
%{_mandir}/man3/IO::AIO.3pm*

%changelog
* Fri Dec 30 2011 Paul Howarth <paul@city-fan.org> - 4.12-1
- Update to 4.12:
  - realpath would return a random value if the name was too long, instead of -1
  - port to c89

* Mon Oct 10 2011 Paul Howarth <paul@city-fan.org> - 4.11-1
- Update to 4.11:
  - libeio didn't compile on !linux
- Drop upstreamed preprocessor patch

* Sun Oct  9 2011 Paul Howarth <paul@city-fan.org> - 4.1-1
- Update to 4.1:
  - IO::AIO accessed uninitialised memory on unsuccessful stats
  - (libeio) added syncfs syscall wrapper
  - (libeio) set thread name on linux (ps -L/Hcx, top, gdb)
  - (libeio) support multiple independent working directories
  - Applied spelling corrections by Nicholas Bamber
  - Tune treescan #threads and #outstanding requests a bit
  - Reduce the number of file descriptors in use at any one time in treescan,
    to avoid running out of them (and using too much RAM)
  - Take advantage of working directory abstractions in aio_scandir and
    treescan
  - Reduce compiled size by ~10% by not inlining some key functionality
  - Added --progress switch to treescan
- BR: perl(Carp)
- Add patch to fix obvious preprocessor error

* Mon Jul 18 2011 Paul Howarth <paul@city-fan.org> - 4.0-2
- Rebuild for perl 5.14.1 in Rawhide

* Mon Jul 18 2011 Paul Howarth <paul@city-fan.org> - 4.0-1
- Update to 4.0:
  - INCOMPATIBLE CHANGE: fork is no longer supported (indeed, it never was);
    see FORK BEHAVIOUR in manpage for details
  - Passes testsuite on win32 now and may actually work
  - (libeio) fix a deadlock where a wakeup signal could be missed when a
    timeout occured at the same time
  - (libeio) added realpath
  - (libeio) added fallocate
  - (libeio) disabling sendfile on darwin unfortunately broke the emulation
  - (libeio) do not acquire any locks when forking
  - (libeio) use fewer time() syscalls when waiting for new requests
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 30 2011 Paul Howarth <paul@city-fan.org> - 3.93-1
- Update to 3.93:
  - Upstream included ecb.h

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 3.92-1
- Update to 3.92:
  - (libeio) work around a Linux (and likely FreeBSD and other kernels) bug
    where sendfile would not transfer all the requested bytes on large
    transfers, using a heuristic
  - Buggy sendfile caused aio_move/copy to sometimes fail for big files
    (fortunately it checks that the whole file has been transferred...)
  - Use libecb for higher performance and higher portability
  - (libeio) disable sendfile on darwin, it's too broken
  - Disable fork tests on !linux, as only linux supports mixing pthread and
    fork in perl
  - Document the fact that fork doesn't work any more when using this module,
    on anything !GNU/Linux
  - Increase timeout in t/04_fork.t, as too many CPAN-tester setups run on a
    0.1MHz cpu (or so)
- Copy missing ecb.h from Coro-6.0 (CPAN RT#69186)

* Fri May 27 2011 Paul Howarth <paul@city-fan.org> - 3.90-1
- Update to 3.9:
  - libeio: fix memory corruption in aio_readdirx for the flags combination
    READDIR_STAT_ORDER | READDIR_DIRS_FIRST
  - Add lots of newer POSIX and GNU/Linux-specific open flags

* Mon Mar 28 2011 Paul Howarth <paul@city-fan.org> - 3.80-1
- Update to 3.8:
  - Use non-standard but maybe-working-on-BSD fork technique
  - Support a max_idle value of 0
  - Support setting of idle timeout value (IO::AIO::idle_timeout)
- Work around perl/rpm versioning incompatibilities
- Nobody else likes macros for commands

* Sat Jan 22 2011 Paul Howarth <paul@city-fan.org> - 3.71-1
- Import from Fedora
- Update to 3.71

* Fri Dec 17 2010 Marcela Maslanova <mmaslano@redhat.com> - 3.65-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Thu Jun 24 2010 Ruben Kerkhof <ruben@rubenkerkhof.com> 3.65-1
- Upstream released new version

* Sun May 02 2010 Marcela Maslanova <mmaslano@redhat.com> - 3.17-5
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 3.17-4
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.17-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.17-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Dec 18 2008 Nicolas Chauvet <kwizart@gmail.com> - 3.17-1
- Update to 3.17

* Sun Nov 09 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.16-1
- Upstream release new version

* Mon Mar 03 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.51-2
- Rebuild for new perl (again)

* Sat Feb 09 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> - 2.51-1
- Sync with upstream

* Thu Feb  7 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.33-2
- Rebuild for new perl

* Sun May 13 2007 Ruben Kerkhof <ruben@rubenkerkhof.com> - 2.33-1
- Initial import
